import 'package:flutter/material.dart';
import 'package:v_base_framework/utils/colors_util.dart';
import 'package:v_components/widgets/popu/v_popup.dart';

class GuidePopup extends StatefulWidget {
  final List<GlobalKey> highlightKeys;

  GuidePopup(this.highlightKeys);

  @override
  _GuidePopupState createState() => _GuidePopupState();

}

class _GuidePopupState extends State<GuidePopup> {
  int highlightIndex = -1;
  double hLeft = 0, hTop = 0, hWidth = 0, hHeight = 0, hRadius = 0;

  @override
  void initState() {
    super.initState();
    Rect? rect = _calculateNextGuide();
    hRadius = 10;
    hLeft = rect!.left;
    hTop = rect.top;
    hHeight = rect.height;
    hWidth = rect.width;
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      behavior: HitTestBehavior.opaque,
      onTap: () => _next(),
      child: Scaffold(
        backgroundColor: Colors.transparent,
        body: Container(
          padding: EdgeInsets.only(
            top: hTop - 50,
            left: hLeft + (hWidth - 300) / 2,
          ),
          child:
             Text('${_getShowText()}',style: TextStyle(
                color: ColorsUtil.hex2Color("#1bbbf2"),
                fontWeight: FontWeight.bold,
                fontSize: 20


              )),
        ),
      ),
    );
  }

  String _getShowText() {
    switch (highlightIndex) {
      case 0:
        return '点击弹出下拉框';
      case 1:
        return '点击弹出步步引导';
      case 2:
        return '点击弹出所有引导';
      case 3:
        return '点击弹出类似dialog';
    }
    return '';
  }

  _next() {
    Rect? rect = _calculateNextGuide();
    if (rect == null) {
      return;
    }
    List<RRect> highlights = [
      RRect.fromRectAndRadius(
        rect,
        Radius.circular(hRadius),
      ),
    ];
    setState(() {
      VPopup.setHighlights(context, highlights);
      hLeft = rect.left;
      hTop = rect.top;
      hHeight = rect.height;
      hWidth = rect.width;
    });
  }

  Rect? _calculateNextGuide() {
    highlightIndex++;
    if (highlightIndex >= widget.highlightKeys.length) {
      _dismiss();
      return null;
    }
    RenderBox? box = widget.highlightKeys[highlightIndex].currentContext
        ?.findRenderObject() as RenderBox;
    Offset offset = box!.localToGlobal(Offset.zero);
    return Rect.fromLTWH(
      offset.dx - 5,
      offset.dy - 5,
      box.size.width + 10,
      box.size.height + 10,
    );
  }

  _dismiss() {
    VPopup.pop(context);
  }
}
